@@ -82,7 +82,7 @@ class DynamoFL(_Base):
                 samples = j['data']['samples']
 
             for p in self.project_participants:
-                if project_key == p['project_key'] and p['datasource_key'] not in samples:
+                if project_key == p['project_key'] and p['datasource_key'] in samples:
                     self.train_and_test_callback(p['datasource_key'], j['data']['project'])
 
         elif j['event'] == 'hyperparams-updated':
